@@ -17,14 +17,18 @@ use warnings;
 
 our $dbg;
 sub debug {
-	print $dbg "@_\n" if $ENV{'DEBUG'};
+	return unless $ENV{'DEBUG'};
+	my $t = time;
+	open ($dbg, '>out.log') unless defined $dbg;
+	*STDERR = *$dbg;
+	print $dbg "$t:@_\n";
 }
 
 package OpenBSD::PackageManager::CursesView;
-our @ISA=(qw(OpenBSD::PkgAdd::State));
-use OpenBSD::Paths;
+#our @ISA=(qw(OpenBSD::PackageManager::View));
 use Curses::UI;
 use Curses;
+use Carp;
 use Text::Wrap;
 use List::Util qw(min max);
 $Text::Wrap::columns = 72;
@@ -32,27 +36,12 @@ $Text::Wrap::columns = 72;
 sub new
 {
 	my($class, $m) = @_;
-	my $self = $class->SUPER::new('mgr');
+	my $self = bless {}, $class;
 	$self->{name} ="pkg_mgr";
 	$self->{model} = $m;
 	return $self;
 }
 
-sub handle_options
-{
-	my ($self,$really,$update) = @_;
-	# check PkgAdd::handle_options & friends
-	$self->{interactive} = 1;
-	$self->{destdir} = '';
-	$self->{localbase} = OpenBSD::Paths->localbase;
-	$self->{not} = $main::not = !$really;
-	$self->{quick} = 2 if ($self->{not});
-	$self->{newupdates} = $update;
-	$self->{allow_replacing} = $update;
-	$self->{update} = $update;
-	$self->progress->setup();
-}
-
 sub show_msg
 {
 	my $self = shift;
@@ -96,7 +85,7 @@ sub show_category
 sub progress
 {
 	my $self = shift;
-	return $self->{progressmeter};
+	return $self->{progressmeter} //= OpenBSD::PackageManager::CursesProgressMeter->new($self);
 }
 
 sub fill_ports_listbox
@@ -356,7 +345,8 @@ sub confirm
 {
 	my ($self, $prompt, $default) = @_;
 	my $result;
-	if (@{$self->{messages_to_confirm}}) {
+	main::debug("confirm0:$prompt");
+	if (defined $self->{messages_to_confirm}) {
 		$prompt = "@{$self->{messages_to_confirm}}$prompt";
 		undef @{$self->{messages_to_confirm}};
 	}
@@ -455,9 +445,37 @@ sub choose_location
 	return $h{$r};
 }
 
-sub check_root
+# copied from OpenBSD/State.pm, formats parameters/placeholders
+sub f
 {
-	# not implemented as we don't force the user to run as root
+	my $self = shift;
+	if (@_ == 0) {
+		return undef;
+	}
+	my ($fmt, @l) = @_;
+	# make it so that #0 is #
+	unshift(@l, '#');
+	$fmt =~ s,\#(\d+),($l[$1] // "<Undefined #$1>"),ge;
+	return $fmt;
+}
+
+sub fatal
+{
+	my $self = shift;
+	main::debug("curses:fatal:@_");
+	croak "fatal!";
+}
+
+sub errprint
+{
+	my $self = shift;
+	main::debug("curses:errprint:@_");
+}
+
+sub print
+{
+	my $self = shift;
+	main::debug("curses:print:@_");
 }
 
 sub say
@@ -474,12 +492,18 @@ sub say
 	}
 }
 
+sub system
+{
+	my $self = shift;
+	$self->{ctrl}->pkg->{install}->{state}->system(@_);
+}
+
 sub errsay
 {
 	my $self = shift;
 	main::debug("Curses->errsay:".$self->f(@_));
 	# if msg related to pkg update @execs
-	if ("@_" =~ /(New|Old|\+ |\- \|.*\@exec)/) {
+	if ("@_" =~ /(can't delete.*without|New|Old|\+ |\- \|.*\@exec)/) {
 		push @{$self->{messages_to_confirm}}, join('',$self->f(@_))."\n"
 	} else {
 		push(@{$self->{context_messages}->{'errors'}}, join('', $self->f(@_)));
@@ -489,14 +513,6 @@ sub errsay
 sub start
 {
 	my $self = shift;
-	open ($dbg, '>out.log') if $ENV{'DEBUG'};
-	$self->{l} = OpenBSD::Log->new;
-	$self->{vstat} = OpenBSD::Vstat->new($self);
-	$self->{status} = OpenBSD::Status->new;
-	$self->{recorder} = OpenBSD::SharedItemsRecorder->new;
-	$self->{progressmeter} = OpenBSD::PackageManager::CursesProgressMeter->new($self);
-	$self->{wantntogo} = 1;
-	$self->{v} = 0;
 	$self->gui_init() unless defined shift;
 }
 
@@ -575,8 +591,10 @@ sub new
 {
 	my $class = shift;
 	my $self = bless {}, $class;
-	$self->{v} = shift;
+	$self->{view} = shift;
+	$self->{state} = $self->{view}->{ctrl}->pkg->{install}->{state};
 	main::debug("CursesProgressMeter: new");
+	$self->setup;
 	return $self;
 }
 
@@ -585,28 +603,17 @@ sub setup
 	my $self = shift;
 	# called normally with -x and -m
 	main::debug("progress:setup");
-	$self->{dialog} = $self->{v}->{wid}{main_win}->add(
+	$self->{dialog} = $self->{view}->{wid}{main_win}->add(
 		'progressdialog', 'Dialog::Progress',
 		-max => 100,
 		-title => 'Work in progress...',
 		);
 }
 
-sub errprint
-{
-	my $self = shift;
-	main::debug("progress:errprint:@_");
-}
-
-sub print
-{
-	my $self = shift;
-	main::debug("progress:print:@_");
-}
-
 sub set_title
 {
 	my ($self, $title) = @_;
+	main::debug("progress:set_title:$title");
 	$self->{dialog}->title($title);
 }
 
@@ -623,6 +630,7 @@ sub show
 {
 	my ($self, $current, $total) = @_;
 	$self->{dialog}->pos(100*$current/$total);
+	main::debug("progress:show:$current/$total");
 	$self->{dialog}->draw();
 }
 
@@ -637,8 +645,8 @@ sub clear
 {
 	my $self = shift;
 	main::debug("progress:clear");
-	sleep (1);
-	$self->{v}->{wid}{main_win}->delete('progressdialog');
+#	sleep (1);
+#	$self->{view}->{wid}{main_win}->delete('progressdialog');
 }
 
 # called after a package is installed to move on to the next
