@@ -18,12 +18,14 @@ use warnings;
 package OpenBSD::PackageManager::Pkg::Add;
 use OpenBSD::PkgAdd;
 our @ISA=(qw(OpenBSD::PkgAdd));
+use OpenBSD::PackageManager::State;
 
 sub new
 {
 	my $class = shift;
-	my $self = {state => shift};
+	my $self = {view => shift};
 	bless ($self, $class);
+	$self->{state} = OpenBSD::PackageManager::PkgAdd::State->new($self->{view});
 	return $self;
 }
 
@@ -39,7 +41,7 @@ $state->{bad} = 0;
 $state->handle_options($really, $update);
 $state->progress->set_title($really ? ($update ? "Updating.." : "Installing..") :  ($update ? "Simulating update.." : "Simulating installation.."));
 local $SIG{'INFO'} = sub { $state->status->print($state); };
-$self->framework($state);
+$self->try_and_run_command($state);
 return $state->{bad} != 0;
 }
 
