@@ -18,12 +18,14 @@ use warnings;
 package OpenBSD::PackageManager::Pkg::Delete;
 use OpenBSD::PkgDelete;
 our @ISA=(qw(OpenBSD::PkgDelete));
+use OpenBSD::PackageManager::State;
 
 sub new
 {
 	my $class = shift;
-	my $self = {state => shift};
+	my $self = {view => shift};
 	bless ($self, $class);
+	$self->{state} = OpenBSD::PackageManager::PkgDelete::State->new($self->{view});
 	return $self;
 }
 
@@ -35,10 +37,10 @@ my $really = shift; # -n
 my $state = $self->{state};
 $state->{bad} = 0;
 @ARGV = @_;
-$state->handle_options($really, 0);
+$state->handle_options($really);
 $state->progress->set_title($really ? "Removing.." : "Simulating removal..");
 local $SIG{'INFO'} = sub { $state->status->print($state); };
-$self->framework($state);
+$self->try_and_run_command($state);
 return $state->{bad} != 0;
 }
 
